@@ -30,6 +30,9 @@ class Excel:
 
         return number_row, number_col
 
+    def get_sheets(self):
+        return [_ for _ in self.wb.sheet_names()]
+
     # Reads the cell
     def cell(self, cell, sheet_name=None):
         sheet_name = sheet_name if sheet_name else self.sheet_name
